Module auth

Module auth 

Authentication module for the ap-proxy crate. Authentication works by creating a cryptographic identity - a signature key-pair. The identity is the public key. It is proven to the proxy, by signing a challenge provided by the proxy using the signature key.

Structs

Challenge
A cryptographic challenge issued by the proxy server for authentication.
ChallengeResponse
A signed response to an authentication challenge.
Identity
A public cryptographic identity.
IdentityFingerprint
A compact SHA256 fingerprint of an Identity.

Enums

IdentityKeyPair
A cryptographic identity key-pair for signing challenges.
SignatureAlgorithm
Signature algorithm selection for key generation.