Authentication module for the ap-proxy crate. Authentication works by creating a cryptographic identity - a signature key-pair. The identity is the public key. It is proven to the proxy, by signing a challenge provided by the proxy using the signature key.
Structs
- Challenge
- A cryptographic challenge issued by the proxy server for authentication.
- Challenge
Response - A signed response to an authentication challenge.
- Identity
- A public cryptographic identity.
- Identity
Fingerprint - A compact SHA256 fingerprint of an
Identity.
Enums
- Identity
KeyPair - A cryptographic identity key-pair for signing challenges.
- Signature
Algorithm - Signature algorithm selection for key generation.