Module error

Module error 

Error types for proxy operations.

This module defines all error conditions that can occur during proxy client and server operations.

Enums

ProxyError
Errors that can occur during proxy client or server operations.